==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/inputs/ChainingTriggerArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.inputs

import com.pulumi.azurenative.datafactory.inputs.ChainingTriggerArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Any
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Trigger that allows the referenced pipeline to depend on other pipeline runs based on runDimension Name/Value pairs. Upstream pipelines should declare the same runDimension Name and their runs should have the values for those runDimensions. The referenced pipeline run would be triggered if the values for the runDimension match for all upstream pipeline runs.
 * @property annotations List of tags that can be used for describing the trigger.
 * @property dependsOn Upstream Pipelines.
 * @property description Trigger description.
 * @property pipeline Pipeline for which runs are created when all upstream pipelines complete successfully.
 * @property runDimension Run Dimension property that needs to be emitted by upstream pipelines.
 * @property type Trigger type.
 * Expected value is 'ChainingTrigger'.
 */
public data class ChainingTriggerArgs(
    public val annotations: Output<List<Any>>? = null,
    public val dependsOn: Output<List<PipelineReferenceArgs>>,
    public val description: Output<String>? = null,
    public val pipeline: Output<TriggerPipelineReferenceArgs>,
    public val runDimension: Output<String>,
    public val type: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.datafactory.inputs.ChainingTriggerArgs> {
    override fun toJava(): com.pulumi.azurenative.datafactory.inputs.ChainingTriggerArgs =
        com.pulumi.azurenative.datafactory.inputs.ChainingTriggerArgs.builder()
            .annotations(annotations?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .dependsOn(
                dependsOn.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .description(description?.applyValue({ args0 -> args0 }))
            .pipeline(pipeline.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .runDimension(runDimension.applyValue({ args0 -> args0 }))
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ChainingTriggerArgs].
 */
@PulumiTagMarker
public class ChainingTriggerArgsBuilder internal constructor() {
    private var annotations: Output<List<Any>>? = null

    private var dependsOn: Output<List<PipelineReferenceArgs>>? = null

    private var description: Output<String>? = null

    private var pipeline: Output<TriggerPipelineReferenceArgs>? = null

    private var runDimension: Output<String>? = null

    private var type: Output<String>? = null

    /**
     * @param value List of tags that can be used for describing the trigger.
     */
    @JvmName("mnaxtmfktjvpnqdu")
    public suspend fun annotations(`value`: Output<List<Any>>) {
        this.annotations = value
    }

    @JvmName("owlyortsokivbcxe")
    public suspend fun annotations(vararg values: Output<Any>) {
        this.annotations = Output.all(values.asList())
    }

    /**
     * @param values List of tags that can be used for describing the trigger.
     */
    @JvmName("dqntaajruefdgqwm")
    public suspend fun annotations(values: List<Output<Any>>) {
        this.annotations = Output.all(values)
    }

    /**
     * @param value Upstream Pipelines.
     */
    @JvmName("irynsajpdnyctyvw")
    public suspend fun dependsOn(`value`: Output<List<PipelineReferenceArgs>>) {
        this.dependsOn = value
    }

    @JvmName("rbbkkynkbkvnvwej")
    public suspend fun dependsOn(vararg values: Output<PipelineReferenceArgs>) {
        this.dependsOn = Output.all(values.asList())
    }

    /**
     * @param values Upstream Pipelines.
     */
    @JvmName("dkhnnfpbbxsggqus")
    public suspend fun dependsOn(values: List<Output<PipelineReferenceArgs>>) {
        this.dependsOn = Output.all(values)
    }

    /**
     * @param value Trigger description.
     */
    @JvmName("redwwlvfwwxfrrsr")
    public suspend fun description(`value`: Output<String>) {
        this.description = value
    }

    /**
     * @param value Pipeline for which runs are created when all upstream pipelines complete successfully.
     */
    @JvmName("xhruqgbqxhdxqswx")
    public suspend fun pipeline(`value`: Output<TriggerPipelineReferenceArgs>) {
        this.pipeline = value
    }

    /**
     * @param value Run Dimension property that needs to be emitted by upstream pipelines.
     */
    @JvmName("cflkuottsjgqtdlt")
    public suspend fun runDimension(`value`: Output<String>) {
        this.runDimension = value
    }

    /**
     * @param value Trigger type.
     * Expected value is 'ChainingTrigger'.
     */
    @JvmName("ioqusmjdxdyhkvlp")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value List of tags that can be used for describing the trigger.
     */
    @JvmName("fohpqcdvyosjragd")
    public suspend fun annotations(`value`: List<Any>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.annotations = mapped
    }

    /**
     * @param values List of tags that can be used for describing the trigger.
     */
    @JvmName("vufddboklmkcrdqy")
    public suspend fun annotations(vararg values: Any) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.annotations = mapped
    }

    /**
     * @param value Upstream Pipelines.
     */
    @JvmName("dnjlqbjchscxxssl")
    public suspend fun dependsOn(`value`: List<PipelineReferenceArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dependsOn = mapped
    }

    /**
     * @param argument Upstream Pipelines.
     */
    @JvmName("kmpftybllnoybbya")
    public suspend fun dependsOn(argument: List<suspend PipelineReferenceArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            PipelineReferenceArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.dependsOn = mapped
    }

    /**
     * @param argument Upstream Pipelines.
     */
    @JvmName("lqfymwrfvdepilkj")
    public suspend fun dependsOn(vararg argument: suspend PipelineReferenceArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            PipelineReferenceArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.dependsOn = mapped
    }

    /**
     * @param argument Upstream Pipelines.
     */
    @JvmName("jhbmsygfeqkuawmb")
    public suspend fun dependsOn(argument: suspend PipelineReferenceArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(PipelineReferenceArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.dependsOn = mapped
    }

    /**
     * @param values Upstream Pipelines.
     */
    @JvmName("oxtiiadcfvaccayb")
    public suspend fun dependsOn(vararg values: PipelineReferenceArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dependsOn = mapped
    }

    /**
     * @param value Trigger description.
     */
    @JvmName("iefrmlgoyatgikxw")
    public suspend fun description(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.description = mapped
    }

    /**
     * @param value Pipeline for which runs are created when all upstream pipelines complete successfully.
     */
    @JvmName("velppndykgtugxyr")
    public suspend fun pipeline(`value`: TriggerPipelineReferenceArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.pipeline = mapped
    }

    /**
     * @param argument Pipeline for which runs are created when all upstream pipelines complete successfully.
     */
    @JvmName("ykrblkwgdffdgrsl")
    public suspend fun pipeline(argument: suspend TriggerPipelineReferenceArgsBuilder.() -> Unit) {
        val toBeMapped = TriggerPipelineReferenceArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.pipeline = mapped
    }

    /**
     * @param value Run Dimension property that needs to be emitted by upstream pipelines.
     */
    @JvmName("hsowmxdjracacvxp")
    public suspend fun runDimension(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.runDimension = mapped
    }

    /**
     * @param value Trigger type.
     * Expected value is 'ChainingTrigger'.
     */
    @JvmName("cwljdiocnrvwfrca")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): ChainingTriggerArgs = ChainingTriggerArgs(
        annotations = annotations,
        dependsOn = dependsOn ?: throw PulumiNullFieldException("dependsOn"),
        description = description,
        pipeline = pipeline ?: throw PulumiNullFieldException("pipeline"),
        runDimension = runDimension ?: throw PulumiNullFieldException("runDimension"),
        type = type ?: throw PulumiNullFieldException("type"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/inputs/ChainingTriggerArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.inputs

import com.pulumi.azurenative.datafactory.inputs.ChainingTriggerArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Any
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Trigger that allows the referenced pipeline to depend on other pipeline runs based on runDimension Name/Value pairs. Upstream pipelines should declare the same runDimension Name and their runs should have the values for those runDimensions. The referenced pipeline run would be triggered if the values for the runDimension match for all upstream pipeline runs.
 * @property annotations List of tags that can be used for describing the trigger.
 * @property dependsOn Upstream Pipelines.
 * @property description Trigger description.
 * @property pipeline Pipeline for which runs are created when all upstream pipelines complete successfully.
 * @property runDimension Run Dimension property that needs to be emitted by upstream pipelines.
 * @property type Trigger type.
 * Expected value is 'ChainingTrigger'.
 */
public data class ChainingTriggerArgs(
    public val annotations: Output<List<Any>>? = null,
    public val dependsOn: Output<List<PipelineReferenceArgs>>,
    public val description: Output<String>? = null,
    public val pipeline: Output<TriggerPipelineReferenceArgs>,
    public val runDimension: Output<String>,
    public val type: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.datafactory.inputs.ChainingTriggerArgs> {
    override fun toJava(): com.pulumi.azurenative.datafactory.inputs.ChainingTriggerArgs =
        com.pulumi.azurenative.datafactory.inputs.ChainingTriggerArgs.builder()
            .annotations(annotations?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .dependsOn(
                dependsOn.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .description(description?.applyValue({ args0 -> args0 }))
            .pipeline(pipeline.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .runDimension(runDimension.applyValue({ args0 -> args0 }))
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ChainingTriggerArgs].
 */
@PulumiTagMarker
public class ChainingTriggerArgsBuilder internal constructor() {
    private var annotations: Output<List<Any>>? = null

    private var dependsOn: Output<List<PipelineReferenceArgs>>? = null

    private var description: Output<String>? = null

    private var pipeline: Output<TriggerPipelineReferenceArgs>? = null

    private var runDimension: Output<String>? = null

    private var type: Output<String>? = null

    /**
     * @param value List of tags that can be used for describing the trigger.
     */
    @JvmName("itadvksvmhhnqatw")
    public suspend fun annotations(`value`: Output<List<Any>>) {
        this.annotations = value
    }

    @JvmName("bioggwvovpqkxbgt")
    public suspend fun annotations(vararg values: Output<Any>) {
        this.annotations = Output.all(values.asList())
    }

    /**
     * @param values List of tags that can be used for describing the trigger.
     */
    @JvmName("ctmxrljgcsojpxqk")
    public suspend fun annotations(values: List<Output<Any>>) {
        this.annotations = Output.all(values)
    }

    /**
     * @param value Upstream Pipelines.
     */
    @JvmName("ibakygooaisehnub")
    public suspend fun dependsOn(`value`: Output<List<PipelineReferenceArgs>>) {
        this.dependsOn = value
    }

    @JvmName("fthrtciashguqnwh")
    public suspend fun dependsOn(vararg values: Output<PipelineReferenceArgs>) {
        this.dependsOn = Output.all(values.asList())
    }

    /**
     * @param values Upstream Pipelines.
     */
    @JvmName("uaiobketwbsbahbv")
    public suspend fun dependsOn(values: List<Output<PipelineReferenceArgs>>) {
        this.dependsOn = Output.all(values)
    }

    /**
     * @param value Trigger description.
     */
    @JvmName("dacjmyfsvjngscxn")
    public suspend fun description(`value`: Output<String>) {
        this.description = value
    }

    /**
     * @param value Pipeline for which runs are created when all upstream pipelines complete successfully.
     */
    @JvmName("xtdhjmhdqsrgyuwi")
    public suspend fun pipeline(`value`: Output<TriggerPipelineReferenceArgs>) {
        this.pipeline = value
    }

    /**
     * @param value Run Dimension property that needs to be emitted by upstream pipelines.
     */
    @JvmName("kvhjdvcclqcyrpbn")
    public suspend fun runDimension(`value`: Output<String>) {
        this.runDimension = value
    }

    /**
     * @param value Trigger type.
     * Expected value is 'ChainingTrigger'.
     */
    @JvmName("yenogengfrnywqdy")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value List of tags that can be used for describing the trigger.
     */
    @JvmName("esknqoltyxxmurmq")
    public suspend fun annotations(`value`: List<Any>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.annotations = mapped
    }

    /**
     * @param values List of tags that can be used for describing the trigger.
     */
    @JvmName("xuprnuuxqakvodgb")
    public suspend fun annotations(vararg values: Any) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.annotations = mapped
    }

    /**
     * @param value Upstream Pipelines.
     */
    @JvmName("bhrbxbdukhdxjiav")
    public suspend fun dependsOn(`value`: List<PipelineReferenceArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dependsOn = mapped
    }

    /**
     * @param argument Upstream Pipelines.
     */
    @JvmName("veurksqgntiicmkt")
    public suspend fun dependsOn(argument: List<suspend PipelineReferenceArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            PipelineReferenceArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.dependsOn = mapped
    }

    /**
     * @param argument Upstream Pipelines.
     */
    @JvmName("mbnkrwobqnhvvpql")
    public suspend fun dependsOn(vararg argument: suspend PipelineReferenceArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            PipelineReferenceArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.dependsOn = mapped
    }

    /**
     * @param argument Upstream Pipelines.
     */
    @JvmName("docvsmqvpueiiudi")
    public suspend fun dependsOn(argument: suspend PipelineReferenceArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(PipelineReferenceArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.dependsOn = mapped
    }

    /**
     * @param values Upstream Pipelines.
     */
    @JvmName("pwplmtlqpekioees")
    public suspend fun dependsOn(vararg values: PipelineReferenceArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dependsOn = mapped
    }

    /**
     * @param value Trigger description.
     */
    @JvmName("jfxqctujubcnaege")
    public suspend fun description(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.description = mapped
    }

    /**
     * @param value Pipeline for which runs are created when all upstream pipelines complete successfully.
     */
    @JvmName("ufquxaeesapplvwe")
    public suspend fun pipeline(`value`: TriggerPipelineReferenceArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.pipeline = mapped
    }

    /**
     * @param argument Pipeline for which runs are created when all upstream pipelines complete successfully.
     */
    @JvmName("mufxytjaoylctibf")
    public suspend fun pipeline(argument: suspend TriggerPipelineReferenceArgsBuilder.() -> Unit) {
        val toBeMapped = TriggerPipelineReferenceArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.pipeline = mapped
    }

    /**
     * @param value Run Dimension property that needs to be emitted by upstream pipelines.
     */
    @JvmName("eouyntqbbqfewlln")
    public suspend fun runDimension(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.runDimension = mapped
    }

    /**
     * @param value Trigger type.
     * Expected value is 'ChainingTrigger'.
     */
    @JvmName("pogcvrviioskexlv")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): ChainingTriggerArgs = ChainingTriggerArgs(
        annotations = annotations,
        dependsOn = dependsOn ?: throw PulumiNullFieldException("dependsOn"),
        description = description,
        pipeline = pipeline ?: throw PulumiNullFieldException("pipeline"),
        runDimension = runDimension ?: throw PulumiNullFieldException("runDimension"),
        type = type ?: throw PulumiNullFieldException("type"),
    )
}
